@@ -8,19 +8,29 @@
   function opConnectTls(
     args,
   ) {
-    return core.opAsync("op_connect_tls", args);
+    return core.opAsync("op_tls_connect", args);
   }
 
   function opAcceptTLS(rid) {
-    return core.opAsync("op_accept_tls", rid);
+    return core.opAsync("op_tls_accept", rid);
   }
 
   function opListenTls(args) {
-    return core.opSync("op_listen_tls", args);
+    return core.opSync("op_tls_listen", args);
   }
 
   function opStartTls(args) {
-    return core.opAsync("op_start_tls", args);
+    return core.opAsync("op_tls_start", args);
+  }
+
+  function opTlsHandshake(rid) {
+    return core.opAsync("op_tls_handshake", rid);
+  }
+
+  class TlsConn extends Conn {
+    handshake() {
+      return opTlsHandshake(this.rid);
+    }
   }
 
   async function connectTls({
@@ -41,13 +51,13 @@
       certChain,
       privateKey,
     });
-    return new Conn(res.rid, res.remoteAddr, res.localAddr);
+    return new TlsConn(res.rid, res.remoteAddr, res.localAddr);
   }
 
-  class TLSListener extends Listener {
+  class TlsListener extends Listener {
     async accept() {
       const res = await opAcceptTLS(this.rid);
-      return new Conn(res.rid, res.remoteAddr, res.localAddr);
+      return new TlsConn(res.rid, res.remoteAddr, res.localAddr);
     }
   }
 
@@ -67,7 +77,7 @@
       transport,
       alpnProtocols,
     });
-    return new TLSListener(res.rid, res.localAddr);
+    return new TlsListener(res.rid, res.localAddr);
   }
 
   async function startTls(
@@ -80,13 +90,14 @@
       certFile,
       caCerts,
     });
-    return new Conn(res.rid, res.remoteAddr, res.localAddr);
+    return new TlsConn(res.rid, res.remoteAddr, res.localAddr);
   }
 
   window.__bootstrap.tls = {
     startTls,
     listenTls,
     connectTls,
-    TLSListener,
+    TlsConn,
+    TlsListener,
   };
 })(this);
